/*
        Danilo Djokic <djokicd@outlook.com>
        Applied Physics and Electronics - Petnica Science Center
        http://ele.petnica.rs/
        Date: 18/9/2015

  - Project name:
     Real-time Histogram Analyser
  
  - Description:
     This project uses Camera Click to implement real-time image
     histogram analysis
     
  - Test configuration:
     MCU:             PIC32MX460F512L
                      https://www.google.rs/search?q=PIC32MX460F512L&ie=&oe=
     Dev.Board:       EasyPIC Fusion v7
                      http://www.mikroe.com/easypic-fusion/
     Oscillator:      XT-PLL, 80.000MHz
     ext. modules:    camera click board  - 
                      http://www.mikroe.com/click/camera/
     SW:              mikroC PRO for PIC32
                      http://www.mikroe.com/mikroc/pic32/
 * NOTES:
     - Place Camera click board in the mikroBUS socket 1.
     - Turn on TFT backlight on SW11.
 */


int x;
int cnt;
char str[16];

#include "resources.h"
#include "CameraDriver.c"
#include "histogram.c"

void InitMCU()
{
  AD1PCFG = 0xFFFF;
  JTAGEN_bit = 0;
  TFT_Set_Default_Mode();
  TFT_Init(320, 240);
  
  TFT_Fill_Screen( CL_BLACK );
  
  delay_ms(10);
  
  SPI2_Init_Advanced(_SPI_MASTER,_SPI_8_BIT, 6, _SPI_SS_DISABLE,_SPI_DATA_SAMPLE_MIDDLE,_SPI_CLK_IDLE_LOW,_SPI_ACTIVE_2_IDLE);
  
  Chip_Select_Dir = 0; // Output;
  Ready_Pin_Dir = 1; // Input;
  Chip_Select = 1; // Deselect all;

  
  delay_ms(1000);
}

void DrawFrame() {  // Drawing the frame
  TFT_Set_Ext_Buffer(Get_Camera_Data);
  TFT_Fill_Screen(CL_WHITE);
  TFT_Set_Pen(CL_RED, 1);
  TFT_Line(20, 220, 300, 220);
  TFT_Line(20,  46, 300,  46);
  TFT_Set_Font(TFT_defaultFont , CL_GREEN, FO_HORIZONTAL);
  TFT_Write_Text("PFE Histogram Analyser", 42, 14);
  TFT_Set_Font(TFT_defaultFont , CL_BLACK, FO_HORIZONTAL);
  TFT_Write_Text("EasyPIC Fusion v7", 19, 223);
  TFT_Set_Font(TFT_defaultFont , CL_BLACK, FO_HORIZONTAL);
  TFT_Write_Text("ele.petnica.rs", 200, 223);
  
  TFT_image_Jpeg(320-60, 2, pfepetnica);
  
  TFT_Set_Pen(CL_BLUE, 1);
  TFT_Rectangle(72, 133, 248, 205);
  

  
  delay_ms(100);
}

void main() {
  InitMCU();
  
  DrawFrame();
  TFT_Set_Font(TFT_defaultFont , CL_BLUE, FO_HORIZONTAL);
  
  draw_h_arrow(258, 207, 10);
  TFT_Write_Text("B", 258-5, 207-6-10);
  
  draw_v_arrow(62, 143+20, 10);
  TFT_Write_Text("%", 52, 150+20);

  TFT_Set_Pen(CL_BLUE, 2);
  TFT_Line(72, 207, 259, 207);

  while(1==1){

        TFT_Ext_Image(72, 61, 0, 1); // Drawing image on (72, 61)
        update_histogram();
        draw_histogram();
  }
}